@@ -15,13 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """
 Example Airflow DAG for Google Cloud Dataflow service
 """
+from __future__ import annotations
+
 import os
-from typing import Callable, Dict, List
-from urllib.parse import urlparse
+from datetime import datetime
+from typing import Callable
+from urllib.parse import urlsplit
 
 from airflow import models
 from airflow.exceptions import AirflowException
@@ -32,6 +34,7 @@ from airflow.providers.apache.beam.operators.beam import (
 from airflow.providers.google.cloud.hooks.dataflow import DataflowJobStatus
 from airflow.providers.google.cloud.operators.dataflow import (
     CheckJobRunning,
+    DataflowStopJobOperator,
     DataflowTemplatedJobStartOperator,
 )
 from airflow.providers.google.cloud.sensors.dataflow import (
@@ -41,30 +44,31 @@ from airflow.providers.google.cloud.sensors.dataflow import (
     DataflowJobStatusSensor,
 )
 from airflow.providers.google.cloud.transfers.gcs_to_local import GCSToLocalFilesystemOperator
-from airflow.utils.dates import days_ago
 
-GCS_TMP = os.environ.get('GCP_DATAFLOW_GCS_TMP', 'gs://INVALID BUCKET NAME/temp/')
-GCS_STAGING = os.environ.get('GCP_DATAFLOW_GCS_STAGING', 'gs://INVALID BUCKET NAME/staging/')
-GCS_OUTPUT = os.environ.get('GCP_DATAFLOW_GCS_OUTPUT', 'gs://INVALID BUCKET NAME/output')
-GCS_JAR = os.environ.get('GCP_DATAFLOW_JAR', 'gs://INVALID BUCKET NAME/word-count-beam-bundled-0.1.jar')
-GCS_PYTHON = os.environ.get('GCP_DATAFLOW_PYTHON', 'gs://INVALID BUCKET NAME/wordcount_debugging.py')
+START_DATE = datetime(2021, 1, 1)
 
-GCS_JAR_PARTS = urlparse(GCS_JAR)
+GCS_TMP = os.environ.get("GCP_DATAFLOW_GCS_TMP", "gs://INVALID BUCKET NAME/temp/")
+GCS_STAGING = os.environ.get("GCP_DATAFLOW_GCS_STAGING", "gs://INVALID BUCKET NAME/staging/")
+GCS_OUTPUT = os.environ.get("GCP_DATAFLOW_GCS_OUTPUT", "gs://INVALID BUCKET NAME/output")
+GCS_JAR = os.environ.get("GCP_DATAFLOW_JAR", "gs://INVALID BUCKET NAME/word-count-beam-bundled-0.1.jar")
+GCS_PYTHON = os.environ.get("GCP_DATAFLOW_PYTHON", "gs://INVALID BUCKET NAME/wordcount_debugging.py")
+
+GCS_JAR_PARTS = urlsplit(GCS_JAR)
 GCS_JAR_BUCKET_NAME = GCS_JAR_PARTS.netloc
 GCS_JAR_OBJECT_NAME = GCS_JAR_PARTS.path[1:]
 
 default_args = {
-    'dataflow_default_options': {
-        'tempLocation': GCS_TMP,
-        'stagingLocation': GCS_STAGING,
+    "dataflow_default_options": {
+        "tempLocation": GCS_TMP,
+        "stagingLocation": GCS_STAGING,
     }
 }
 
 with models.DAG(
     "example_gcp_dataflow_native_java",
-    schedule_interval='@once',  # Override to match your needs
-    start_date=days_ago(1),
-    tags=['example'],
+    start_date=START_DATE,
+    catchup=False,
+    tags=["example"],
 ) as dag_native_java:
 
     # [START howto_operator_start_java_job_jar_on_gcs]
@@ -72,12 +76,12 @@ with models.DAG(
         task_id="start-java-job",
         jar=GCS_JAR,
         pipeline_options={
-            'output': GCS_OUTPUT,
+            "output": GCS_OUTPUT,
         },
-        job_class='org.apache.beam.examples.WordCount',
+        job_class="org.apache.beam.examples.WordCount",
         dataflow_config={
             "check_if_running": CheckJobRunning.IgnoreJob,
-            "location": 'europe-west3',
+            "location": "europe-west3",
             "poll_sleep": 10,
         },
     )
@@ -95,12 +99,12 @@ with models.DAG(
         task_id="start-java-job-local",
         jar="/tmp/dataflow-{{ ds_nodash }}.jar",
         pipeline_options={
-            'output': GCS_OUTPUT,
+            "output": GCS_OUTPUT,
         },
-        job_class='org.apache.beam.examples.WordCount',
+        job_class="org.apache.beam.examples.WordCount",
         dataflow_config={
             "check_if_running": CheckJobRunning.WaitForRun,
-            "location": 'europe-west3',
+            "location": "europe-west3",
             "poll_sleep": 10,
         },
     )
@@ -110,9 +114,9 @@ with models.DAG(
 with models.DAG(
     "example_gcp_dataflow_native_python",
     default_args=default_args,
-    start_date=days_ago(1),
-    schedule_interval='@once',  # Override to match your needs
-    tags=['example'],
+    start_date=START_DATE,
+    catchup=False,
+    tags=["example"],
 ) as dag_native_python:
 
     # [START howto_operator_start_python_job]
@@ -121,33 +125,33 @@ with models.DAG(
         py_file=GCS_PYTHON,
         py_options=[],
         pipeline_options={
-            'output': GCS_OUTPUT,
+            "output": GCS_OUTPUT,
         },
-        py_requirements=['apache-beam[gcp]==2.21.0'],
-        py_interpreter='python3',
+        py_requirements=["apache-beam[gcp]==2.21.0"],
+        py_interpreter="python3",
         py_system_site_packages=False,
-        dataflow_config={'location': 'europe-west3'},
+        dataflow_config={"location": "europe-west3"},
     )
     # [END howto_operator_start_python_job]
 
     start_python_job_local = BeamRunPythonPipelineOperator(
         task_id="start-python-job-local",
-        py_file='apache_beam.examples.wordcount',
-        py_options=['-m'],
+        py_file="apache_beam.examples.wordcount",
+        py_options=["-m"],
         pipeline_options={
-            'output': GCS_OUTPUT,
+            "output": GCS_OUTPUT,
         },
-        py_requirements=['apache-beam[gcp]==2.14.0'],
-        py_interpreter='python3',
+        py_requirements=["apache-beam[gcp]==2.14.0"],
+        py_interpreter="python3",
         py_system_site_packages=False,
     )
 
 with models.DAG(
     "example_gcp_dataflow_native_python_async",
     default_args=default_args,
-    start_date=days_ago(1),
-    schedule_interval='@once',  # Override to match your needs
-    tags=['example'],
+    start_date=START_DATE,
+    catchup=False,
+    tags=["example"],
 ) as dag_native_python_async:
     # [START howto_operator_start_python_job_async]
     start_python_job_async = BeamRunPythonPipelineOperator(
@@ -156,14 +160,14 @@ with models.DAG(
         py_file=GCS_PYTHON,
         py_options=[],
         pipeline_options={
-            'output': GCS_OUTPUT,
+            "output": GCS_OUTPUT,
         },
-        py_requirements=['apache-beam[gcp]==2.25.0'],
-        py_interpreter='python3',
+        py_requirements=["apache-beam[gcp]==2.25.0"],
+        py_interpreter="python3",
         py_system_site_packages=False,
         dataflow_config={
             "job_name": "start-python-job-async",
-            "location": 'europe-west3',
+            "location": "europe-west3",
             "wait_until_finished": False,
         },
     )
@@ -172,9 +176,9 @@ with models.DAG(
     # [START howto_sensor_wait_for_job_status]
     wait_for_python_job_async_done = DataflowJobStatusSensor(
         task_id="wait-for-python-job-async-done",
-        job_id="{{task_instance.xcom_pull('start-python-job-async')['dataflow_job_id']}}",
+        job_id="{{task_instance.xcom_pull('start-python-job-async')['id']}}",
         expected_statuses={DataflowJobStatus.JOB_STATE_DONE},
-        location='europe-west3',
+        location="europe-west3",
     )
     # [END howto_sensor_wait_for_job_status]
 
@@ -182,7 +186,7 @@ with models.DAG(
     def check_metric_scalar_gte(metric_name: str, value: int) -> Callable:
         """Check is metric greater than equals to given value."""
 
-        def callback(metrics: List[Dict]) -> bool:
+        def callback(metrics: list[dict]) -> bool:
             dag_native_python_async.log.info("Looking for '%s' >= %d", metric_name, value)
             for metric in metrics:
                 context = metric.get("name", {}).get("context", {})
@@ -196,15 +200,15 @@ with models.DAG(
 
     wait_for_python_job_async_metric = DataflowJobMetricsSensor(
         task_id="wait-for-python-job-async-metric",
-        job_id="{{task_instance.xcom_pull('start-python-job-async')['dataflow_job_id']}}",
-        location='europe-west3',
+        job_id="{{task_instance.xcom_pull('start-python-job-async')['id']}}",
+        location="europe-west3",
         callback=check_metric_scalar_gte(metric_name="Service-cpu_num_seconds", value=100),
         fail_on_terminal_state=False,
     )
     # [END howto_sensor_wait_for_job_metric]
 
     # [START howto_sensor_wait_for_job_message]
-    def check_message(messages: List[dict]) -> bool:
+    def check_message(messages: list[dict]) -> bool:
         """Check message"""
         for message in messages:
             if "Adding workflow start and stop steps." in message.get("messageText", ""):
@@ -213,15 +217,15 @@ with models.DAG(
 
     wait_for_python_job_async_message = DataflowJobMessagesSensor(
         task_id="wait-for-python-job-async-message",
-        job_id="{{task_instance.xcom_pull('start-python-job-async')['dataflow_job_id']}}",
-        location='europe-west3',
+        job_id="{{task_instance.xcom_pull('start-python-job-async')['id']}}",
+        location="europe-west3",
         callback=check_message,
         fail_on_terminal_state=False,
     )
     # [END howto_sensor_wait_for_job_message]
 
     # [START howto_sensor_wait_for_job_autoscaling_event]
-    def check_autoscaling_event(autoscaling_events: List[dict]) -> bool:
+    def check_autoscaling_event(autoscaling_events: list[dict]) -> bool:
         """Check autoscaling event"""
         for autoscaling_event in autoscaling_events:
             if "Worker pool started." in autoscaling_event.get("description", {}).get("messageText", ""):
@@ -230,8 +234,8 @@ with models.DAG(
 
     wait_for_python_job_async_autoscaling_event = DataflowJobAutoScalingEventsSensor(
         task_id="wait-for-python-job-async-autoscaling-event",
-        job_id="{{task_instance.xcom_pull('start-python-job-async')['dataflow_job_id']}}",
-        location='europe-west3',
+        job_id="{{task_instance.xcom_pull('start-python-job-async')['id']}}",
+        location="europe-west3",
         callback=check_autoscaling_event,
         fail_on_terminal_state=False,
     )
@@ -246,15 +250,39 @@ with models.DAG(
 with models.DAG(
     "example_gcp_dataflow_template",
     default_args=default_args,
-    start_date=days_ago(1),
-    schedule_interval='@once',  # Override to match your needs
-    tags=['example'],
+    start_date=START_DATE,
+    catchup=False,
+    tags=["example"],
 ) as dag_template:
     # [START howto_operator_start_template_job]
     start_template_job = DataflowTemplatedJobStartOperator(
         task_id="start-template-job",
-        template='gs://dataflow-templates/latest/Word_Count',
-        parameters={'inputFile': "gs://dataflow-samples/shakespeare/kinglear.txt", 'output': GCS_OUTPUT},
-        location='europe-west3',
+        template="gs://dataflow-templates/latest/Word_Count",
+        parameters={"inputFile": "gs://dataflow-samples/shakespeare/kinglear.txt", "output": GCS_OUTPUT},
+        location="europe-west3",
     )
     # [END howto_operator_start_template_job]
+
+with models.DAG(
+    "example_gcp_stop_dataflow_job",
+    default_args=default_args,
+    start_date=START_DATE,
+    catchup=False,
+    tags=["example"],
+) as dag_template:
+    # [START howto_operator_stop_dataflow_job]
+    stop_dataflow_job = DataflowStopJobOperator(
+        task_id="stop-dataflow-job",
+        location="europe-west3",
+        job_name_prefix="start-template-job",
+    )
+    # [END howto_operator_stop_dataflow_job]
+    start_template_job = DataflowTemplatedJobStartOperator(
+        task_id="start-template-job",
+        template="gs://dataflow-templates/latest/Word_Count",
+        parameters={"inputFile": "gs://dataflow-samples/shakespeare/kinglear.txt", "output": GCS_OUTPUT},
+        location="europe-west3",
+        append_job_name=False,
+    )
+
+    stop_dataflow_job >> start_template_job
