@@ -15,7 +15,6 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """
 This module contains a CloudDLPHook
 which allows you to connect to Google Cloud DLP service.
@@ -25,11 +24,13 @@ which allows you to connect to Google Cloud DLP service.
     ImageRedactionConfig
     RedactImageRequest
 """
+from __future__ import annotations
 
 import re
 import time
-from typing import List, Optional, Sequence, Tuple, Union
+from typing import Sequence
 
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.dlp_v2 import DlpServiceClient
 from google.cloud.dlp_v2.types import (
@@ -87,8 +88,8 @@ class CloudDLPHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -102,10 +103,9 @@ class CloudDLPHook(GoogleBaseHook):
         Provides a client for interacting with the Cloud DLP API.
 
         :return: Google Cloud DLP API Client
-        :rtype: google.cloud.dlp_v2.DlpServiceClient
         """
         if not self._client:
-            self._client = DlpServiceClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
+            self._client = DlpServiceClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._client
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -113,9 +113,9 @@ class CloudDLPHook(GoogleBaseHook):
         self,
         dlp_job_id: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Starts asynchronous cancellation on a long-running DLP job.
@@ -141,13 +141,13 @@ class CloudDLPHook(GoogleBaseHook):
 
     def create_deidentify_template(
         self,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        deidentify_template: Optional[Union[dict, DeidentifyTemplate]] = None,
-        template_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        deidentify_template: dict | DeidentifyTemplate | None = None,
+        template_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> DeidentifyTemplate:
         """
         Creates a deidentify template for re-using frequently used configuration for
@@ -166,7 +166,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.DeidentifyTemplate
         """
         client = self.get_conn()
         # Handle project_id from connection configuration
@@ -192,12 +191,12 @@ class CloudDLPHook(GoogleBaseHook):
     def create_dlp_job(
         self,
         project_id: str = PROVIDE_PROJECT_ID,
-        inspect_job: Optional[Union[dict, InspectJobConfig]] = None,
-        risk_job: Optional[Union[dict, RiskAnalysisJobConfig]] = None,
-        job_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        inspect_job: dict | InspectJobConfig | None = None,
+        risk_job: dict | RiskAnalysisJobConfig | None = None,
+        job_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         wait_until_finished: bool = True,
         time_to_sleep_in_seconds: int = 60,
     ) -> DlpJob:
@@ -218,7 +217,6 @@ class CloudDLPHook(GoogleBaseHook):
         :param metadata: (Optional) Additional metadata that is provided to the method.
         :param wait_until_finished: (Optional) If true, it will keep polling the job state
             until it is set to DONE.
-        :rtype: google.cloud.dlp_v2.types.DlpJob
         :param time_to_sleep_in_seconds: (Optional) Time to sleep, in seconds, between active checks
             of the operation results. Defaults to 60.
         """
@@ -265,13 +263,13 @@ class CloudDLPHook(GoogleBaseHook):
 
     def create_inspect_template(
         self,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        inspect_template: Optional[InspectTemplate] = None,
-        template_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        inspect_template: InspectTemplate | None = None,
+        template_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> InspectTemplate:
         """
         Creates an inspect template for re-using frequently used configuration for
@@ -290,7 +288,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.InspectTemplate
         """
         client = self.get_conn()
 
@@ -317,11 +314,11 @@ class CloudDLPHook(GoogleBaseHook):
     def create_job_trigger(
         self,
         project_id: str = PROVIDE_PROJECT_ID,
-        job_trigger: Optional[Union[dict, JobTrigger]] = None,
-        trigger_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        job_trigger: dict | JobTrigger | None = None,
+        trigger_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> JobTrigger:
         """
         Creates a job trigger to run DLP actions such as scanning storage for sensitive
@@ -338,7 +335,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.JobTrigger
         """
         client = self.get_conn()
 
@@ -354,13 +350,13 @@ class CloudDLPHook(GoogleBaseHook):
 
     def create_stored_info_type(
         self,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        config: Optional[Union[dict, StoredInfoTypeConfig]] = None,
-        stored_info_type_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        config: dict | StoredInfoTypeConfig | None = None,
+        stored_info_type_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> StoredInfoType:
         """
         Creates a pre-built stored info type to be used for inspection.
@@ -378,7 +374,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.StoredInfoType
         """
         client = self.get_conn()
 
@@ -405,14 +400,14 @@ class CloudDLPHook(GoogleBaseHook):
     def deidentify_content(
         self,
         project_id: str = PROVIDE_PROJECT_ID,
-        deidentify_config: Optional[Union[dict, DeidentifyConfig]] = None,
-        inspect_config: Optional[Union[dict, InspectConfig]] = None,
-        item: Optional[Union[dict, ContentItem]] = None,
-        inspect_template_name: Optional[str] = None,
-        deidentify_template_name: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        deidentify_config: dict | DeidentifyConfig | None = None,
+        inspect_config: dict | InspectConfig | None = None,
+        item: dict | ContentItem | None = None,
+        inspect_template_name: str | None = None,
+        deidentify_template_name: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> DeidentifyContentResponse:
         """
         De-identifies potentially sensitive info from a content item. This method has limits
@@ -438,7 +433,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.DeidentifyContentResponse
         """
         client = self.get_conn()
 
@@ -456,7 +450,7 @@ class CloudDLPHook(GoogleBaseHook):
         )
 
     def delete_deidentify_template(
-        self, template_id, organization_id=None, project_id=None, retry=None, timeout=None, metadata=()
+        self, template_id, organization_id=None, project_id=None, retry=DEFAULT, timeout=None, metadata=()
     ) -> None:
         """
         Deletes a deidentify template.
@@ -496,9 +490,9 @@ class CloudDLPHook(GoogleBaseHook):
         self,
         dlp_job_id: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes a long-running DLP job. This method indicates that the client is no longer
@@ -526,11 +520,11 @@ class CloudDLPHook(GoogleBaseHook):
     def delete_inspect_template(
         self,
         template_id: str,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes an inspect template.
@@ -570,9 +564,9 @@ class CloudDLPHook(GoogleBaseHook):
         self,
         job_trigger_id: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes a job trigger.
@@ -599,11 +593,11 @@ class CloudDLPHook(GoogleBaseHook):
     def delete_stored_info_type(
         self,
         stored_info_type_id: str,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes a stored info type.
@@ -641,11 +635,11 @@ class CloudDLPHook(GoogleBaseHook):
     def get_deidentify_template(
         self,
         template_id: str,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> DeidentifyTemplate:
         """
         Gets a deidentify template.
@@ -662,7 +656,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.DeidentifyTemplate
         """
         client = self.get_conn()
 
@@ -686,9 +679,9 @@ class CloudDLPHook(GoogleBaseHook):
         self,
         dlp_job_id: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> DlpJob:
         """
         Gets the latest state of a long-running Dlp Job.
@@ -703,7 +696,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.DlpJob
         """
         client = self.get_conn()
 
@@ -716,11 +708,11 @@ class CloudDLPHook(GoogleBaseHook):
     def get_inspect_template(
         self,
         template_id: str,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> InspectTemplate:
         """
         Gets an inspect template.
@@ -737,7 +729,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.InspectTemplate
         """
         client = self.get_conn()
 
@@ -761,9 +752,9 @@ class CloudDLPHook(GoogleBaseHook):
         self,
         job_trigger_id: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> JobTrigger:
         """
         Gets a DLP job trigger.
@@ -778,7 +769,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.JobTrigger
         """
         client = self.get_conn()
 
@@ -791,11 +781,11 @@ class CloudDLPHook(GoogleBaseHook):
     def get_stored_info_type(
         self,
         stored_info_type_id: str,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> StoredInfoType:
         """
         Gets a stored info type.
@@ -812,7 +802,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.StoredInfoType
         """
         client = self.get_conn()
 
@@ -835,12 +824,12 @@ class CloudDLPHook(GoogleBaseHook):
     def inspect_content(
         self,
         project_id: str,
-        inspect_config: Optional[Union[dict, InspectConfig]] = None,
-        item: Optional[Union[dict, ContentItem]] = None,
-        inspect_template_name: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        inspect_config: dict | InspectConfig | None = None,
+        item: dict | ContentItem | None = None,
+        inspect_template_name: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> InspectContentResponse:
         """
         Finds potentially sensitive info in content. This method has limits on input size,
@@ -860,7 +849,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.InspectContentResponse
         """
         client = self.get_conn()
 
@@ -877,14 +865,14 @@ class CloudDLPHook(GoogleBaseHook):
 
     def list_deidentify_templates(
         self,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        page_size: Optional[int] = None,
-        order_by: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-    ) -> List[DeidentifyTemplate]:
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        page_size: int | None = None,
+        order_by: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> list[DeidentifyTemplate]:
         """
         Lists deidentify templates.
 
@@ -903,7 +891,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: List[google.cloud.dlp_v2.types.DeidentifyTemplate]
         """
         client = self.get_conn()
 
@@ -932,14 +919,14 @@ class CloudDLPHook(GoogleBaseHook):
     def list_dlp_jobs(
         self,
         project_id: str,
-        results_filter: Optional[str] = None,
-        page_size: Optional[int] = None,
-        job_type: Optional[str] = None,
-        order_by: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-    ) -> List[DlpJob]:
+        results_filter: str | None = None,
+        page_size: int | None = None,
+        job_type: str | None = None,
+        order_by: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> list[DlpJob]:
         """
         Lists DLP jobs that match the specified filter in the request.
 
@@ -958,7 +945,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: List[google.cloud.dlp_v2.types.DlpJob]
         """
         client = self.get_conn()
 
@@ -977,11 +963,11 @@ class CloudDLPHook(GoogleBaseHook):
 
     def list_info_types(
         self,
-        language_code: Optional[str] = None,
-        results_filter: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        language_code: str | None = None,
+        results_filter: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> ListInfoTypesResponse:
         """
         Returns a list of the sensitive information types that the DLP API supports.
@@ -996,7 +982,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.ListInfoTypesResponse
         """
         client = self.get_conn()
 
@@ -1010,14 +995,14 @@ class CloudDLPHook(GoogleBaseHook):
 
     def list_inspect_templates(
         self,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        page_size: Optional[int] = None,
-        order_by: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-    ) -> List[InspectTemplate]:
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        page_size: int | None = None,
+        order_by: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> list[InspectTemplate]:
         """
         Lists inspect templates.
 
@@ -1036,7 +1021,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: List[google.cloud.dlp_v2.types.InspectTemplate]
         """
         client = self.get_conn()
 
@@ -1064,13 +1048,13 @@ class CloudDLPHook(GoogleBaseHook):
     def list_job_triggers(
         self,
         project_id: str,
-        page_size: Optional[int] = None,
-        order_by: Optional[str] = None,
-        results_filter: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-    ) -> List[JobTrigger]:
+        page_size: int | None = None,
+        order_by: str | None = None,
+        results_filter: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> list[JobTrigger]:
         """
         Lists job triggers.
 
@@ -1088,7 +1072,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: List[google.cloud.dlp_v2.types.JobTrigger]
         """
         client = self.get_conn()
 
@@ -1106,14 +1089,14 @@ class CloudDLPHook(GoogleBaseHook):
 
     def list_stored_info_types(
         self,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        page_size: Optional[int] = None,
-        order_by: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-    ) -> List[StoredInfoType]:
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        page_size: int | None = None,
+        order_by: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> list[StoredInfoType]:
         """
         Lists stored info types.
 
@@ -1132,7 +1115,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: List[google.cloud.dlp_v2.types.StoredInfoType]
         """
         client = self.get_conn()
 
@@ -1160,15 +1142,13 @@ class CloudDLPHook(GoogleBaseHook):
     def redact_image(
         self,
         project_id: str,
-        inspect_config: Optional[Union[dict, InspectConfig]] = None,
-        image_redaction_configs: Optional[
-            Union[List[dict], List[RedactImageRequest.ImageRedactionConfig]]
-        ] = None,
-        include_findings: Optional[bool] = None,
-        byte_item: Optional[Union[dict, ByteContentItem]] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        inspect_config: dict | InspectConfig | None = None,
+        image_redaction_configs: None | (list[dict] | list[RedactImageRequest.ImageRedactionConfig]) = None,
+        include_findings: bool | None = None,
+        byte_item: dict | ByteContentItem | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> RedactImageResponse:
         """
         Redacts potentially sensitive info from an image. This method has limits on
@@ -1181,7 +1161,7 @@ class CloudDLPHook(GoogleBaseHook):
             here will override the template referenced by the inspect_template_name argument.
         :param image_redaction_configs: (Optional) The configuration for specifying what
             content to redact from images.
-            List[google.cloud.dlp_v2.types.RedactImageRequest.ImageRedactionConfig]
+            list[google.cloud.dlp_v2.types.RedactImageRequest.ImageRedactionConfig]
         :param include_findings: (Optional) Whether the response should include findings
             along with the redacted image.
         :param byte_item: (Optional) The content must be PNG, JPEG, SVG or BMP.
@@ -1191,7 +1171,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.RedactImageResponse
         """
         client = self.get_conn()
 
@@ -1211,14 +1190,14 @@ class CloudDLPHook(GoogleBaseHook):
     def reidentify_content(
         self,
         project_id: str,
-        reidentify_config: Optional[Union[dict, DeidentifyConfig]] = None,
-        inspect_config: Optional[Union[dict, InspectConfig]] = None,
-        item: Optional[Union[dict, ContentItem]] = None,
-        inspect_template_name: Optional[str] = None,
-        reidentify_template_name: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        reidentify_config: dict | DeidentifyConfig | None = None,
+        inspect_config: dict | InspectConfig | None = None,
+        item: dict | ContentItem | None = None,
+        inspect_template_name: str | None = None,
+        reidentify_template_name: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> ReidentifyContentResponse:
         """
         Re-identifies content that has been de-identified.
@@ -1241,7 +1220,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.ReidentifyContentResponse
         """
         client = self.get_conn()
 
@@ -1261,13 +1239,13 @@ class CloudDLPHook(GoogleBaseHook):
     def update_deidentify_template(
         self,
         template_id: str,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        deidentify_template: Optional[Union[dict, DeidentifyTemplate]] = None,
-        update_mask: Optional[Union[dict, FieldMask]] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        deidentify_template: dict | DeidentifyTemplate | None = None,
+        update_mask: dict | FieldMask | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> DeidentifyTemplate:
         """
         Updates the deidentify template.
@@ -1286,7 +1264,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.DeidentifyTemplate
         """
         client = self.get_conn()
 
@@ -1315,13 +1292,13 @@ class CloudDLPHook(GoogleBaseHook):
     def update_inspect_template(
         self,
         template_id: str,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        inspect_template: Optional[Union[dict, InspectTemplate]] = None,
-        update_mask: Optional[Union[dict, FieldMask]] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        inspect_template: dict | InspectTemplate | None = None,
+        update_mask: dict | FieldMask | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> InspectTemplate:
         """
         Updates the inspect template.
@@ -1340,7 +1317,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.InspectTemplate
         """
         client = self.get_conn()
 
@@ -1370,11 +1346,11 @@ class CloudDLPHook(GoogleBaseHook):
         self,
         job_trigger_id: str,
         project_id: str,
-        job_trigger: Optional[Union[dict, JobTrigger]] = None,
-        update_mask: Optional[Union[dict, FieldMask]] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        job_trigger: dict | JobTrigger | None = None,
+        update_mask: dict | FieldMask | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> JobTrigger:
         """
         Updates a job trigger.
@@ -1391,7 +1367,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.JobTrigger
         """
         client = self.get_conn()
 
@@ -1411,13 +1386,13 @@ class CloudDLPHook(GoogleBaseHook):
     def update_stored_info_type(
         self,
         stored_info_type_id: str,
-        organization_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        config: Optional[Union[dict, StoredInfoTypeConfig]] = None,
-        update_mask: Optional[Union[dict, FieldMask]] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        organization_id: str | None = None,
+        project_id: str | None = None,
+        config: dict | StoredInfoTypeConfig | None = None,
+        update_mask: dict | FieldMask | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> StoredInfoType:
         """
         Updates the stored info type by creating a new version.
@@ -1437,7 +1412,6 @@ class CloudDLPHook(GoogleBaseHook):
             to complete. Note that if retry is specified, the timeout applies to each
             individual attempt.
         :param metadata: (Optional) Additional metadata that is provided to the method.
-        :rtype: google.cloud.dlp_v2.types.StoredInfoType
         """
         client = self.get_conn()
 
