@@ -15,6 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Dataplex operators."""
+
 from __future__ import annotations
 
 from time import sleep
@@ -25,12 +26,16 @@ if TYPE_CHECKING:
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry, exponential_sleep_generator
-from google.cloud.dataplex_v1.types import Task
+from google.cloud.dataplex_v1.types import Lake, Task
 from googleapiclient.errors import HttpError
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.dataplex import DataplexHook
-from airflow.providers.google.cloud.links.dataplex import DataplexTaskLink, DataplexTasksLink
+from airflow.providers.google.cloud.links.dataplex import (
+    DataplexLakeLink,
+    DataplexTaskLink,
+    DataplexTasksLink,
+)
 
 
 class DataplexCreateTaskOperator(BaseOperator):
@@ -74,7 +79,7 @@ class DataplexCreateTaskOperator(BaseOperator):
         "delegate_to",
         "impersonation_chain",
     )
-    template_fields_renderers = {'body': 'json'}
+    template_fields_renderers = {"body": "json"}
     operator_extra_links = (DataplexTaskLink(),)
 
     def __init__(
@@ -143,7 +148,7 @@ class DataplexCreateTaskOperator(BaseOperator):
                 self.log.info("Is operation done already? %s", is_done)
                 return is_done
         except HttpError as err:
-            if err.resp.status not in (409, '409'):
+            if err.resp.status not in (409, "409"):
                 raise
             self.log.info("Task %s already exists", self.dataplex_task_id)
             # Wait for task to be ready
@@ -157,7 +162,7 @@ class DataplexCreateTaskOperator(BaseOperator):
                     timeout=self.timeout,
                     metadata=self.metadata,
                 )
-                if task['state'] != 'CREATING':
+                if task["state"] != "CREATING":
                     break
                 sleep(time_to_wait)
 
@@ -427,4 +432,214 @@ class DataplexGetTaskOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        DataplexTasksLink.persist(context=context, task_instance=self)
         return Task.to_dict(task)
+
+
+class DataplexCreateLakeOperator(BaseOperator):
+    """
+    Creates a lake resource within a lake.
+
+    :param project_id: Required. The ID of the Google Cloud project that the lake belongs to.
+    :param region: Required. The ID of the Google Cloud region that the lake belongs to.
+    :param lake_id: Required. Lake identifier.
+    :param body:  Required. The Request body contains an instance of Lake.
+    :param validate_only: Optional. Only validate the request, but do not perform mutations. The default is
+        false.
+    :param api_version: The version of the api that will be requested for example 'v1'.
+    :param retry: A retry object used  to retry requests. If `None` is specified, requests
+        will not be retried.
+    :param timeout: The amount of time, in seconds, to wait for the request to complete.
+        Note that if `retry` is specified, the timeout applies to each individual attempt.
+    :param metadata: Additional metadata that is provided to the method.
+    :param gcp_conn_id: The connection ID to use when fetching connection info.
+    :param delegate_to: The account to impersonate, if any. For this to work, the service account making the
+        request must have domain-wide delegation enabled.
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account (templated).
+    :param asynchronous: Flag informing should the Dataplex lake be created asynchronously.
+        This is useful for long running creating lakes and
+        waiting on them asynchronously using the DataplexLakeSensor
+    """
+
+    template_fields = (
+        "project_id",
+        "lake_id",
+        "body",
+        "validate_only",
+        "delegate_to",
+        "impersonation_chain",
+    )
+    template_fields_renderers = {"body": "json"}
+    operator_extra_links = (DataplexLakeLink(),)
+
+    def __init__(
+        self,
+        project_id: str,
+        region: str,
+        lake_id: str,
+        body: dict[str, Any],
+        validate_only: bool | None = None,
+        api_version: str = "v1",
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
+        asynchronous: bool = False,
+        *args,
+        **kwargs,
+    ) -> None:
+        super().__init__(*args, **kwargs)
+        self.project_id = project_id
+        self.region = region
+        self.lake_id = lake_id
+        self.body = body
+        self.validate_only = validate_only
+        self.api_version = api_version
+        self.retry = retry
+        self.timeout = timeout
+        self.metadata = metadata
+        self.gcp_conn_id = gcp_conn_id
+        self.delegate_to = delegate_to
+        self.impersonation_chain = impersonation_chain
+        self.asynchronous = asynchronous
+
+    def execute(self, context: Context) -> dict:
+        hook = DataplexHook(
+            gcp_conn_id=self.gcp_conn_id,
+            delegate_to=self.delegate_to,
+            api_version=self.api_version,
+            impersonation_chain=self.impersonation_chain,
+        )
+        self.log.info("Creating Dataplex lake %s", self.lake_id)
+
+        try:
+            operation = hook.create_lake(
+                project_id=self.project_id,
+                region=self.region,
+                lake_id=self.lake_id,
+                body=self.body,
+                validate_only=self.validate_only,
+                retry=self.retry,
+                timeout=self.timeout,
+                metadata=self.metadata,
+            )
+            if not self.asynchronous:
+                self.log.info("Waiting for Dataplex lake %s to be created", self.lake_id)
+                lake = hook.wait_for_operation(timeout=self.timeout, operation=operation)
+                self.log.info("Lake %s created successfully", self.lake_id)
+            else:
+                is_done = operation.done()
+                self.log.info("Is operation done already? %s", is_done)
+                return is_done
+        except HttpError as err:
+            if err.resp.status not in (409, "409"):
+                raise
+            self.log.info("Lake %s already exists", self.lake_id)
+            # Wait for lake to be ready
+            for time_to_wait in exponential_sleep_generator(initial=10, maximum=120):
+                lake = hook.get_lake(
+                    project_id=self.project_id,
+                    region=self.region,
+                    lake_id=self.lake_id,
+                    retry=self.retry,
+                    timeout=self.timeout,
+                    metadata=self.metadata,
+                )
+                if lake["state"] != "CREATING":
+                    break
+                sleep(time_to_wait)
+        DataplexLakeLink.persist(
+            context=context,
+            task_instance=self,
+        )
+        return Lake.to_dict(lake)
+
+
+class DataplexDeleteLakeOperator(BaseOperator):
+    """
+    Delete the lake resource.
+
+    :param project_id: Required. The ID of the Google Cloud project that the lake belongs to.
+    :param region: Required. The ID of the Google Cloud region that the lake belongs to.
+    :param lake_id: Required. Lake identifier.
+    :param api_version: The version of the api that will be requested for example 'v1'.
+    :param retry: A retry object used  to retry requests. If `None` is specified, requests
+        will not be retried.
+    :param timeout: The amount of time, in seconds, to wait for the request to complete.
+        Note that if `retry` is specified, the timeout applies to each individual attempt.
+    :param metadata: Additional metadata that is provided to the method.
+    :param gcp_conn_id: The connection ID to use when fetching connection info.
+    :param delegate_to: The account to impersonate, if any. For this to work, the service account making the
+        request must have domain-wide delegation enabled.
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account (templated).
+    """
+
+    template_fields = ("project_id", "lake_id", "delegate_to", "impersonation_chain")
+    operator_extra_links = (DataplexLakeLink(),)
+
+    def __init__(
+        self,
+        project_id: str,
+        region: str,
+        lake_id: str,
+        api_version: str = "v1",
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
+        *args,
+        **kwargs,
+    ) -> None:
+
+        super().__init__(*args, **kwargs)
+        self.project_id = project_id
+        self.region = region
+        self.lake_id = lake_id
+        self.api_version = api_version
+        self.retry = retry
+        self.timeout = timeout
+        self.metadata = metadata
+        self.gcp_conn_id = gcp_conn_id
+        self.delegate_to = delegate_to
+        self.impersonation_chain = impersonation_chain
+
+    def execute(self, context: Context) -> None:
+
+        hook = DataplexHook(
+            gcp_conn_id=self.gcp_conn_id,
+            delegate_to=self.delegate_to,
+            api_version=self.api_version,
+            impersonation_chain=self.impersonation_chain,
+        )
+
+        self.log.info("Deleting Dataplex lake %s", self.lake_id)
+
+        operation = hook.delete_lake(
+            project_id=self.project_id,
+            region=self.region,
+            lake_id=self.lake_id,
+            retry=self.retry,
+            timeout=self.timeout,
+            metadata=self.metadata,
+        )
+        DataplexLakeLink.persist(context=context, task_instance=self)
+        hook.wait_for_operation(timeout=self.timeout, operation=operation)
+        self.log.info("Dataplex lake %s deleted successfully!", self.lake_id)
