@@ -15,9 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains Google Datastore operators."""
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -72,11 +73,11 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'namespace',
-        'entity_filter',
-        'labels',
-        'impersonation_chain',
+        "bucket",
+        "namespace",
+        "entity_filter",
+        "labels",
+        "impersonation_chain",
     )
     operator_extra_links = (StorageLink(),)
 
@@ -84,16 +85,16 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
         self,
         *,
         bucket: str,
-        namespace: Optional[str] = None,
-        datastore_conn_id: str = 'google_cloud_default',
-        cloud_storage_conn_id: str = 'google_cloud_default',
-        delegate_to: Optional[str] = None,
-        entity_filter: Optional[dict] = None,
-        labels: Optional[dict] = None,
+        namespace: str | None = None,
+        datastore_conn_id: str = "google_cloud_default",
+        cloud_storage_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        entity_filter: dict | None = None,
+        labels: dict | None = None,
         polling_interval_in_seconds: int = 10,
         overwrite_existing: bool = False,
-        project_id: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -109,8 +110,8 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
         self.project_id = project_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
-        self.log.info('Exporting data to Cloud Storage bucket %s', self.bucket)
+    def execute(self, context: Context) -> dict:
+        self.log.info("Exporting data to Cloud Storage bucket %s", self.bucket)
 
         if self.overwrite_existing and self.namespace:
             gcs_hook = GCSHook(self.cloud_storage_conn_id, impersonation_chain=self.impersonation_chain)
@@ -130,16 +131,17 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
             labels=self.labels,
             project_id=self.project_id,
         )
-        operation_name = result['name']
+        operation_name = result["name"]
         result = ds_hook.poll_operation_until_done(operation_name, self.polling_interval_in_seconds)
 
-        state = result['metadata']['common']['state']
-        if state != 'SUCCESSFUL':
-            raise AirflowException(f'Operation failed: result={result}')
+        state = result["metadata"]["common"]["state"]
+        if state != "SUCCESSFUL":
+            raise AirflowException(f"Operation failed: result={result}")
         StorageLink.persist(
             context=context,
             task_instance=self,
             uri=f"{self.bucket}/{result['response']['outputUrl'].split('/')[3]}",
+            project_id=self.project_id or ds_hook.project_id,
         )
         return result
 
@@ -181,12 +183,12 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'file',
-        'namespace',
-        'entity_filter',
-        'labels',
-        'impersonation_chain',
+        "bucket",
+        "file",
+        "namespace",
+        "entity_filter",
+        "labels",
+        "impersonation_chain",
     )
     operator_extra_links = (CloudDatastoreImportExportLink(),)
 
@@ -195,14 +197,14 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
         *,
         bucket: str,
         file: str,
-        namespace: Optional[str] = None,
-        entity_filter: Optional[dict] = None,
-        labels: Optional[dict] = None,
-        datastore_conn_id: str = 'google_cloud_default',
-        delegate_to: Optional[str] = None,
+        namespace: str | None = None,
+        entity_filter: dict | None = None,
+        labels: dict | None = None,
+        datastore_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
         polling_interval_in_seconds: float = 10,
-        project_id: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -217,8 +219,8 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
         self.project_id = project_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
-        self.log.info('Importing data from Cloud Storage bucket %s', self.bucket)
+    def execute(self, context: Context):
+        self.log.info("Importing data from Cloud Storage bucket %s", self.bucket)
         ds_hook = DatastoreHook(
             self.datastore_conn_id,
             self.delegate_to,
@@ -232,12 +234,12 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
             labels=self.labels,
             project_id=self.project_id,
         )
-        operation_name = result['name']
+        operation_name = result["name"]
         result = ds_hook.poll_operation_until_done(operation_name, self.polling_interval_in_seconds)
 
-        state = result['metadata']['common']['state']
-        if state != 'SUCCESSFUL':
-            raise AirflowException(f'Operation failed: result={result}')
+        state = result["metadata"]["common"]["state"]
+        if state != "SUCCESSFUL":
+            raise AirflowException(f"Operation failed: result={result}")
 
         CloudDatastoreImportExportLink.persist(context=context, task_instance=self)
         return result
@@ -279,11 +281,11 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
     def __init__(
         self,
         *,
-        partial_keys: List,
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        partial_keys: list,
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -294,7 +296,7 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> list:
+    def execute(self, context: Context) -> list:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -342,11 +344,11 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
     def __init__(
         self,
         *,
-        transaction_options: Dict[str, Any],
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        transaction_options: dict[str, Any],
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -357,7 +359,7 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> str:
+    def execute(self, context: Context) -> str:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -405,11 +407,11 @@ class CloudDatastoreCommitOperator(BaseOperator):
     def __init__(
         self,
         *,
-        body: Dict[str, Any],
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        body: dict[str, Any],
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -420,7 +422,7 @@ class CloudDatastoreCommitOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -469,10 +471,10 @@ class CloudDatastoreRollbackOperator(BaseOperator):
         self,
         *,
         transaction: str,
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -483,7 +485,7 @@ class CloudDatastoreRollbackOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -529,11 +531,11 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
     def __init__(
         self,
         *,
-        body: Dict[str, Any],
-        project_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        body: dict[str, Any],
+        project_id: str | None = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -544,7 +546,7 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -591,9 +593,9 @@ class CloudDatastoreGetOperationOperator(BaseOperator):
         self,
         *,
         name: str,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -603,7 +605,7 @@ class CloudDatastoreGetOperationOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -647,9 +649,9 @@ class CloudDatastoreDeleteOperationOperator(BaseOperator):
         self,
         *,
         name: str,
-        delegate_to: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -659,7 +661,7 @@ class CloudDatastoreDeleteOperationOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = DatastoreHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
