@@ -81,12 +81,12 @@ class GKEDeleteClusterOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'project_id',
-        'gcp_conn_id',
-        'name',
-        'location',
-        'api_version',
-        'impersonation_chain',
+        "project_id",
+        "gcp_conn_id",
+        "name",
+        "location",
+        "api_version",
+        "impersonation_chain",
     )
 
     def __init__(
@@ -95,8 +95,8 @@ class GKEDeleteClusterOperator(BaseOperator):
         name: str,
         location: str,
         project_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        api_version: str = 'v2',
+        gcp_conn_id: str = "google_cloud_default",
+        api_version: str = "v2",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -112,8 +112,8 @@ class GKEDeleteClusterOperator(BaseOperator):
 
     def _check_input(self) -> None:
         if not all([self.project_id, self.name, self.location]):
-            self.log.error('One of (project_id, name, location) is missing or incorrect')
-            raise AirflowException('Operator has incorrect or missing input.')
+            self.log.error("One of (project_id, name, location) is missing or incorrect")
+            raise AirflowException("Operator has incorrect or missing input.")
 
     def execute(self, context: Context) -> str | None:
         hook = GKEHook(
@@ -177,12 +177,12 @@ class GKECreateClusterOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'project_id',
-        'gcp_conn_id',
-        'location',
-        'api_version',
-        'body',
-        'impersonation_chain',
+        "project_id",
+        "gcp_conn_id",
+        "location",
+        "api_version",
+        "body",
+        "impersonation_chain",
     )
     operator_extra_links = (KubernetesEngineClusterLink(),)
 
@@ -192,8 +192,8 @@ class GKECreateClusterOperator(BaseOperator):
         location: str,
         body: dict | Cluster | None,
         project_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        api_version: str = 'v2',
+        gcp_conn_id: str = "google_cloud_default",
+        api_version: str = "v2",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -210,7 +210,7 @@ class GKECreateClusterOperator(BaseOperator):
     def _check_input(self) -> None:
         if (
             not all([self.project_id, self.location, self.body])
-            or (isinstance(self.body, dict) and not ("name" in self.body))
+            or (isinstance(self.body, dict) and "name" not in self.body)
             or (
                 isinstance(self.body, dict)
                 and ("initial_node_count" not in self.body and "node_pools" not in self.body)
@@ -296,7 +296,7 @@ class GKEStartPodOperator(KubernetesPodOperator):
     """
 
     template_fields: Sequence[str] = tuple(
-        {'project_id', 'location', 'cluster_name'} | set(KubernetesPodOperator.template_fields)
+        {"project_id", "location", "cluster_name"} | set(KubernetesPodOperator.template_fields)
     )
     operator_extra_links = (KubernetesEnginePodLink(),)
 
@@ -307,7 +307,7 @@ class GKEStartPodOperator(KubernetesPodOperator):
         cluster_name: str,
         use_internal_ip: bool = False,
         project_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
+        gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         regional: bool = False,
         is_delete_operator_pod: bool | None = None,
@@ -398,17 +398,17 @@ class GKEStartPodOperator(KubernetesPodOperator):
 
                 cmd.extend(
                     [
-                        '--impersonate-service-account',
+                        "--impersonate-service-account",
                         impersonation_account,
                     ]
                 )
             if regional:
-                cmd.append('--region')
+                cmd.append("--region")
             else:
-                cmd.append('--zone')
+                cmd.append("--zone")
             cmd.append(location)
             if use_internal_ip:
-                cmd.append('--internal-ip')
+                cmd.append("--internal-ip")
             execute_in_subprocess(cmd)
 
             # Tell `KubernetesPodOperator` where the config file is located
