@@ -20,11 +20,15 @@ from __future__ import annotations
 
 import os
 import textwrap
-from datetime import datetime
+from datetime import datetime, timedelta
 from typing import TYPE_CHECKING, Callable, Sequence
 
+from google.api_core.retry import Retry
+from google.cloud.storage.retry import DEFAULT_RETRY
+
 from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
+from airflow.providers.google.cloud.triggers.gcs import GCSBlobTrigger
 from airflow.sensors.base import BaseSensorOperator, poke_mode_only
 
 if TYPE_CHECKING:
@@ -51,23 +55,25 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
+    :param retry: (Optional) How to retry the RPC
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'object',
-        'impersonation_chain',
+        "bucket",
+        "object",
+        "impersonation_chain",
     )
-    ui_color = '#f0eee4'
+    ui_color = "#f0eee4"
 
     def __init__(
         self,
         *,
         bucket: str,
         object: str,
-        google_cloud_conn_id: str = 'google_cloud_default',
+        google_cloud_conn_id: str = "google_cloud_default",
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        retry: Retry = DEFAULT_RETRY,
         **kwargs,
     ) -> None:
 
@@ -77,15 +83,65 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
         self.google_cloud_conn_id = google_cloud_conn_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
+        self.retry = retry
 
     def poke(self, context: Context) -> bool:
-        self.log.info('Sensor checks existence of : %s, %s', self.bucket, self.object)
+        self.log.info("Sensor checks existence of : %s, %s", self.bucket, self.object)
         hook = GCSHook(
             gcp_conn_id=self.google_cloud_conn_id,
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
-        return hook.exists(self.bucket, self.object)
+        return hook.exists(self.bucket, self.object, self.retry)
+
+
+class GCSObjectExistenceAsyncSensor(GCSObjectExistenceSensor):
+    """
+    Checks for the existence of a file in Google Cloud Storage .
+
+    :param bucket: The Google Cloud Storage bucket where the object is.
+    :param object: The name of the object to check in the Google cloud storage bucket.
+    :param google_cloud_conn_id: The connection ID to use when connecting to Google Cloud Storage.
+    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
+        if any. For this to work, the service account making the request must have
+        domain-wide delegation enabled.
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account (templated).
+    """
+
+    def execute(self, context: Context) -> None:
+        """Airflow runs this method on the worker and defers using the trigger."""
+        self.defer(
+            timeout=timedelta(seconds=self.timeout),
+            trigger=GCSBlobTrigger(
+                bucket=self.bucket,
+                object_name=self.object,
+                poke_interval=self.poke_interval,
+                google_cloud_conn_id=self.google_cloud_conn_id,
+                hook_params={
+                    "delegate_to": self.delegate_to,
+                    "impersonation_chain": self.impersonation_chain,
+                },
+            ),
+            method_name="execute_complete",
+        )
+
+    def execute_complete(self, context: Context, event: dict[str, str]) -> str:
+        """
+        Callback for when the trigger fires - returns immediately.
+        Relies on trigger to throw an exception, otherwise it assumes execution was
+        successful.
+        """
+        if event["status"] == "error":
+            raise AirflowException(event["message"])
+        self.log.info("File %s was found in bucket %s.", self.object, self.bucket)
+        return event["message"]
 
 
 def ts_function(context):
@@ -127,18 +183,18 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'object',
-        'impersonation_chain',
+        "bucket",
+        "object",
+        "impersonation_chain",
     )
-    ui_color = '#f0eee4'
+    ui_color = "#f0eee4"
 
     def __init__(
         self,
         bucket: str,
         object: str,
         ts_func: Callable = ts_function,
-        google_cloud_conn_id: str = 'google_cloud_default',
+        google_cloud_conn_id: str = "google_cloud_default",
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -153,7 +209,7 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
         self.impersonation_chain = impersonation_chain
 
     def poke(self, context: Context) -> bool:
-        self.log.info('Sensor checks existence of : %s, %s', self.bucket, self.object)
+        self.log.info("Sensor checks existence of : %s, %s", self.bucket, self.object)
         hook = GCSHook(
             gcp_conn_id=self.google_cloud_conn_id,
             delegate_to=self.delegate_to,
@@ -189,17 +245,17 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'prefix',
-        'impersonation_chain',
+        "bucket",
+        "prefix",
+        "impersonation_chain",
     )
-    ui_color = '#f0eee4'
+    ui_color = "#f0eee4"
 
     def __init__(
         self,
         bucket: str,
         prefix: str,
-        google_cloud_conn_id: str = 'google_cloud_default',
+        google_cloud_conn_id: str = "google_cloud_default",
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -213,7 +269,7 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
         self.impersonation_chain = impersonation_chain
 
     def poke(self, context: Context) -> bool:
-        self.log.info('Sensor checks existence of objects: %s, %s', self.bucket, self.prefix)
+        self.log.info("Sensor checks existence of objects: %s, %s", self.bucket, self.prefix)
         hook = GCSHook(
             gcp_conn_id=self.google_cloud_conn_id,
             delegate_to=self.delegate_to,
@@ -275,11 +331,11 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
     """
 
     template_fields: Sequence[str] = (
-        'bucket',
-        'prefix',
-        'impersonation_chain',
+        "bucket",
+        "prefix",
+        "impersonation_chain",
     )
-    ui_color = '#f0eee4'
+    ui_color = "#f0eee4"
 
     def __init__(
         self,
@@ -289,7 +345,7 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
         min_objects: int = 1,
         previous_objects: set[str] | None = None,
         allow_delete: bool = True,
-        google_cloud_conn_id: str = 'google_cloud_default',
+        google_cloud_conn_id: str = "google_cloud_default",
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
