@@ -16,9 +16,11 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Analytics 360 operators."""
+from __future__ import annotations
+
 import csv
 from tempfile import NamedTemporaryFile
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
@@ -43,9 +45,7 @@ class GoogleAnalyticsListAccountsOperator(BaseOperator):
         :ref:`howto/operator:GoogleAnalyticsListAccountsOperator`
 
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -54,7 +54,6 @@ class GoogleAnalyticsListAccountsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -68,7 +67,7 @@ class GoogleAnalyticsListAccountsOperator(BaseOperator):
         *,
         api_version: str = "v3",
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -77,7 +76,7 @@ class GoogleAnalyticsListAccountsOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> List[Dict[str, Any]]:
+    def execute(self, context: Context) -> list[dict[str, Any]]:
         hook = GoogleAnalyticsHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
@@ -100,11 +99,8 @@ class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
         :ref:`howto/operator:GoogleAnalyticsGetAdsLinkOperator`
 
     :param account_id: ID of the account which the given web property belongs to.
-    :type account_id: str
     :param web_property_ad_words_link_id: Web property-Google Ads link ID.
-    :type web_property_ad_words_link_id: str
     :param web_property_id: Web property ID to retrieve the Google Ads link for.
-    :type web_property_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -113,7 +109,6 @@ class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -133,7 +128,7 @@ class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
         web_property_id: str,
         api_version: str = "v3",
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -145,7 +140,7 @@ class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> Dict[str, Any]:
+    def execute(self, context: Context) -> dict[str, Any]:
         hook = GoogleAnalyticsHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
@@ -172,9 +167,7 @@ class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
         :ref:`howto/operator:GoogleAnalyticsRetrieveAdsLinksListOperator`
 
     :param account_id: ID of the account which the given web property belongs to.
-    :type account_id: str
     :param web_property_id: Web property UA-string to retrieve the Google Ads links for.
-    :type web_property_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -183,7 +176,6 @@ class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -201,7 +193,7 @@ class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
         web_property_id: str,
         api_version: str = "v3",
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -212,7 +204,7 @@ class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> List[Dict[str, Any]]:
+    def execute(self, context: Context) -> list[dict[str, Any]]:
         hook = GoogleAnalyticsHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
@@ -230,28 +222,19 @@ class GoogleAnalyticsDataImportUploadOperator(BaseOperator):
     Take a file from Cloud Storage and uploads it to GA via data import API.
 
     :param storage_bucket: The Google cloud storage bucket where the file is stored.
-    :type storage_bucket: str
     :param storage_name_object: The name of the object in the desired Google cloud
           storage bucket. (templated) If the destination points to an existing
           folder, the file will be taken from the specified folder.
-    :type storage_name_object: str
     :param account_id: The GA account Id (long) to which the data upload belongs.
-    :type account_id: str
     :param web_property_id: The web property UA-string associated with the upload.
-    :type web_property_id: str
     :param custom_data_source_id: The id to which the data import belongs
-    :type custom_data_source_id: str
     :param resumable_upload: flag to upload the file in a resumable fashion, using a
         series of at least two requests.
-    :type resumable_upload: bool
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -260,7 +243,6 @@ class GoogleAnalyticsDataImportUploadOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -279,9 +261,9 @@ class GoogleAnalyticsDataImportUploadOperator(BaseOperator):
         custom_data_source_id: str,
         resumable_upload: bool = False,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
+        delegate_to: str | None = None,
         api_version: str = "v3",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -296,7 +278,7 @@ class GoogleAnalyticsDataImportUploadOperator(BaseOperator):
         self.api_version = api_version
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         gcs_hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -336,19 +318,13 @@ class GoogleAnalyticsDeletePreviousDataUploadsOperator(BaseOperator):
     Deletes previous GA uploads to leave the latest file to control the size of the Data Set Quota.
 
     :param account_id: The GA account Id (long) to which the data upload belongs.
-    :type account_id: str
     :param web_property_id: The web property UA-string associated with the upload.
-    :type web_property_id: str
     :param custom_data_source_id: The id to which the data import belongs.
-    :type custom_data_source_id: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -357,7 +333,6 @@ class GoogleAnalyticsDeletePreviousDataUploadsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = ("impersonation_chain",)
@@ -368,9 +343,9 @@ class GoogleAnalyticsDeletePreviousDataUploadsOperator(BaseOperator):
         web_property_id: str,
         custom_data_source_id: str,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
+        delegate_to: str | None = None,
         api_version: str = "v3",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -383,7 +358,7 @@ class GoogleAnalyticsDeletePreviousDataUploadsOperator(BaseOperator):
         self.api_version = api_version
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         ga_hook = GoogleAnalyticsHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -415,22 +390,17 @@ class GoogleAnalyticsModifyFileHeadersDataImportOperator(BaseOperator):
     match the custom dimension ID in GA i.e clientId : dimensionX.
 
     :param storage_bucket: The Google cloud storage bucket where the file is stored.
-    :type storage_bucket: str
     :param storage_name_object: The name of the object in the desired Google cloud
           storage bucket. (templated) If the destination points to an existing
           folder, the file will be taken from the specified folder.
-    :type storage_name_object: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param custom_dimension_header_mapping: Dictionary to handle when uploading
           custom dimensions which have generic IDs ie. 'dimensionX' which are
           set by GA. Dictionary maps the current CSV header to GA ID which will
           be the new header for the CSV to upload to GA eg clientId : dimension1.
-    :type custom_dimension_header_mapping: dict
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -439,7 +409,6 @@ class GoogleAnalyticsModifyFileHeadersDataImportOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -453,9 +422,9 @@ class GoogleAnalyticsModifyFileHeadersDataImportOperator(BaseOperator):
         storage_bucket: str,
         storage_name_object: str,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        custom_dimension_header_mapping: Optional[Dict[str, str]] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        custom_dimension_header_mapping: dict[str, str] | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -467,7 +436,7 @@ class GoogleAnalyticsModifyFileHeadersDataImportOperator(BaseOperator):
         self.impersonation_chain = impersonation_chain
 
     def _modify_column_headers(
-        self, tmp_file_location: str, custom_dimension_header_mapping: Dict[str, str]
+        self, tmp_file_location: str, custom_dimension_header_mapping: dict[str, str]
     ) -> None:
         # Check headers
         self.log.info("Checking if file contains headers")
@@ -499,7 +468,7 @@ class GoogleAnalyticsModifyFileHeadersDataImportOperator(BaseOperator):
         with open(tmp_file_location, "w") as write_file:
             write_file.writelines(all_data)
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         gcs_hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
